@@ -2,8 +2,8 @@ from __future__ import absolute_import
 
 import uuid
 
-from sqlalchemy import types
-from sqlalchemy.dialects import postgresql
+from sqlalchemy import types, util
+from sqlalchemy.dialects import mssql, postgresql
 
 from .scalar_coercible import ScalarCoercible
 
@@ -35,11 +35,18 @@ class UUIDType(types.TypeDecorator, ScalarCoercible):
         self.binary = binary
         self.native = native
 
+    def __repr__(self):
+        return util.generic_repr(self)
+
     def load_dialect_impl(self, dialect):
         if dialect.name == 'postgresql' and self.native:
             # Use the native UUID type.
             return dialect.type_descriptor(postgresql.UUID())
 
+        if dialect.name == 'mssql' and self.native:
+            # Use the native UNIQUEIDENTIFIER type.
+            return dialect.type_descriptor(mssql.UNIQUEIDENTIFIER())
+
         else:
             # Fallback to either a BINARY or a CHAR.
             kind = self.impl if self.binary else types.CHAR(32)
@@ -63,7 +70,7 @@ class UUIDType(types.TypeDecorator, ScalarCoercible):
         if not isinstance(value, uuid.UUID):
             value = self._coerce(value)
 
-        if self.native and dialect.name == 'postgresql':
+        if self.native and dialect.name in ('postgresql', 'mssql'):
             return str(value)
 
         return value.bytes if self.binary else value.hex
@@ -72,7 +79,11 @@ class UUIDType(types.TypeDecorator, ScalarCoercible):
         if value is None:
             return value
 
-        if self.native and dialect.name == 'postgresql':
+        if self.native and dialect.name in ('postgresql', 'mssql'):
+            if isinstance(value, uuid.UUID):
+                # Some drivers convert PostgreSQL's uuid values to
+                # Python's uuid.UUID objects by themselves
+                return value
             return uuid.UUID(value)
 
         return uuid.UUID(bytes=value) if self.binary else uuid.UUID(value)
